searchData={"items":[{"type":"module","title":"Ratelix","doc":"Provides a unified API for rate limiting using either the Leaky Bucket or Token Bucket algorithms.\n\nThis module allows you to start, interact with, and reset rate limiter processes by name.\nThe specific algorithm and its configuration are determined by the options provided at startup.","ref":"Ratelix.html"},{"type":"module","title":"Supported Algorithms - Ratelix","doc":"* `:leaky_bucket` - Processes requests at a fixed interval, rejecting new requests when full.\n  * `:token_bucket` - Allows bursts up to a capacity, refilling tokens at a fixed rate.","ref":"Ratelix.html#module-supported-algorithms"},{"type":"module","title":"Example - Ratelix","doc":"# Start a leaky bucket limiter\n    {:ok, _pid} = Ratelix.start_link(:my_leaky, algorithm: :leaky_bucket, capacity: 5, interval: 1)\n    Ratelix.wait_for_turn(:my_leaky)\n\n    # Start a token bucket limiter\n    {:ok, _pid} = Ratelix.start_link(:my_token, algorithm: :token_bucket, capacity: 10, rate: 2, interval: 1)\n    Ratelix.wait_for_turn(:my_token)","ref":"Ratelix.html#module-example"},{"type":"function","title":"Ratelix.bucket_stats/1","doc":"Returns the current state of the rate limiter for the given name.","ref":"Ratelix.html#bucket_stats/1"},{"type":"type","title":"Ratelix.leaky_bucket_opts/0","doc":"Options for starting a Leaky Bucket rate limiter.\n\n  * `:algorithm` - must be `:leaky_bucket`\n  * `:capacity` - maximum number of requests in the bucket (required)\n  * `:interval` - time interval in seconds (default: 1)","ref":"Ratelix.html#t:leaky_bucket_opts/0"},{"type":"type","title":"Ratelix.name/0","doc":"","ref":"Ratelix.html#t:name/0"},{"type":"type","title":"Ratelix.options/0","doc":"Options for starting a rate limiter. Must be either `leaky_bucket_opts` or `token_bucket_opts`.","ref":"Ratelix.html#t:options/0"},{"type":"function","title":"Ratelix.start_process/2","doc":"Starts a rate limiter child process registered under the given name.","ref":"Ratelix.html#start_process/2"},{"type":"function","title":"Options - Ratelix.start_process/2","doc":"* `:algorithm` - The rate limiting algorithm (`:leaky_bucket` or `:token_bucket`). **Required**.\n  * Other options are passed to the respective bucket module.","ref":"Ratelix.html#start_process/2-options"},{"type":"function","title":"Returns - Ratelix.start_process/2","doc":"* `{:ok, pid}` on success.\n  * `{:error, reason}` on failure.","ref":"Ratelix.html#start_process/2-returns"},{"type":"type","title":"Ratelix.t/0","doc":"","ref":"Ratelix.html#t:t/0"},{"type":"type","title":"Ratelix.token_bucket_opts/0","doc":"Options for starting a Token Bucket rate limiter.\n\n  * `:algorithm` - must be `:token_bucket`\n  * `:capacity` - maximum number of tokens in the bucket (default: 5)\n  * `:rate` - number of tokens added per interval (default: 1)\n  * `:interval` - time interval in seconds for token refill (default: 1)","ref":"Ratelix.html#t:token_bucket_opts/0"},{"type":"function","title":"Ratelix.wait_for_turn/1","doc":"Requests permission to proceed according to the rate limiter's policy.\n\nReturns `:ok` if allowed, or an error tuple if not.","ref":"Ratelix.html#wait_for_turn/1"},{"type":"module","title":"Ratelix.LeakyBucket","doc":"Implements a Leaky Bucket rate limiter as a GenServer.","ref":"Ratelix.LeakyBucket.html"},{"type":"function","title":"Ratelix.LeakyBucket.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Ratelix.LeakyBucket.html#child_spec/1"},{"type":"type","title":"Ratelix.LeakyBucket.t/0","doc":"","ref":"Ratelix.LeakyBucket.html#t:t/0"},{"type":"module","title":"Ratelix.TokenBucket","doc":"Implements a Token Bucket rate limiter as a GenServer.","ref":"Ratelix.TokenBucket.html"},{"type":"function","title":"Ratelix.TokenBucket.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Ratelix.TokenBucket.html#child_spec/1"},{"type":"type","title":"Ratelix.TokenBucket.t/0","doc":"","ref":"Ratelix.TokenBucket.html#t:t/0"},{"type":"extras","title":"Ratelix","doc":"# Ratelix [![CI](https://github.com/elixir-plug/mime/actions/workflows/ci.yml/badge.svg)](https://github.com/GBMayombe/ratelix/actions/workflows/ci.yml) [![Hex Docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/ratelix/)\n\nAn Elixir library that provides robust, concurrent-safe rate limiting using two classic algorithms: **Leaky Bucket** and **Token Bucket**. It is designed for use in distributed systems, APIs, background jobs, or anywhere you need to control the rate of operations.","ref":"readme.html"},{"type":"extras","title":"Features - Ratelix","doc":"- **Leaky Bucket**: Queues requests and processes them at a fixed rate. Excess requests are rejected if the bucket is full.\n- **Token Bucket**: Allows bursts up to a set capacity, refilling tokens at a configurable rate.\n- **GenServer-based**: Each limiter runs as a supervised process, supporting concurrency and fault-tolerance.\n- **Named Limiters**: Start and interact with multiple independent limiters by name.\n- **Unified API**: Interact with both algorithms using a single, simple interface.","ref":"readme.html#features"},{"type":"extras","title":"Installation - Ratelix","doc":"Add `ratelix` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ratelix, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Ratelix","doc":">","ref":"readme.html#usage"},{"type":"extras","title":"Warning - Ratelix","doc":">\n> Ensure `ratelix` application is started.","ref":"readme.html#warning"},{"type":"extras","title":"Starting a Rate Limiter - Ratelix","doc":"You can start a rate limiter process with either algorithm:\n\n#### Leaky Bucket\n\n```elixir\n{:ok, _pid} = Ratelix.start_process(:my_leaky, algorithm: :leaky_bucket, capacity: 5, interval: 1)\n```\n\n- `:capacity` - Maximum number of requests that can be queued (required)\n- `:interval` - Time interval in seconds over which the capacity is enforced (default: 1)\n\n#### Token Bucket\n\n```elixir\n{:ok, _pid} = Ratelix.start_process(:my_token, algorithm: :token_bucket, capacity: 10, rate: 2, interval: 1)\n```\n\n- `:capacity` - Maximum number of tokens in the bucket (default: 5)\n- `:rate` - Number of tokens added per interval (default: 1)\n- `:interval` - Time interval in seconds for token refill (default: 1)","ref":"readme.html#starting-a-rate-limiter"},{"type":"extras","title":"Requesting Permission - Ratelix","doc":"To check if an action is allowed (and update the limiter’s state):\n\n```elixir\ncase Ratelix.wait_for_turn(:my_leaky) do\n  :ok -> do_the_thing()\n  {:error, reason} -> handle_rate_limit(reason)\nend\n```","ref":"readme.html#requesting-permission"},{"type":"extras","title":"Checking Limiter State - Ratelix","doc":"```elixir\nRatelix.bucket_stats(:my_leaky)\n```","ref":"readme.html#checking-limiter-state"},{"type":"extras","title":"Example - Ratelix","doc":"```elixir\n{:ok, _pid} = Ratelix.start_process(:api_limiter, algorithm: :leaky_bucket, capacity: 10, interval: 1)\n\nfor _ <- 1..12 do\n  IO.inspect Ratelix.wait_for_turn(:api_limiter)\nend\n```","ref":"readme.html#example"},{"type":"extras","title":"Algorithms - Ratelix","doc":"","ref":"readme.html#algorithms"},{"type":"extras","title":"Leaky Bucket - Ratelix","doc":"- Requests are queued up to `:capacity`.\n- Requests are processed at a fixed interval.\n- If the bucket is full, new requests are rejected with `{:error, :bucket_full}`.","ref":"readme.html#leaky-bucket"},{"type":"extras","title":"Token Bucket - Ratelix","doc":"- Each request consumes a token.\n- Tokens are refilled at a fixed rate up to `:capacity`.\n- If no tokens are available, requests are rejected with `{:error, :no_token}`.","ref":"readme.html#token-bucket"},{"type":"extras","title":"When to Use - Ratelix","doc":"- **Leaky Bucket**: When you want a steady, constant rate of processing (e.g., smoothing out bursts).\n- **Token Bucket**: When you want to allow short bursts but enforce an average rate over time.","ref":"readme.html#when-to-use"},{"type":"extras","title":"Contributing - Ratelix","doc":"Before submitting a PR, ensure you run `mix check` and all checks passes\nsuccessfully.","ref":"readme.html#contributing"},{"type":"extras","title":"Version Bumps - Ratelix","doc":"This project adheres to [Semantic Versioning][semantic-versioning],\nwhich means the version number will follow the format `MAJOR.MINOR.PATCH`.\n\nAlso, the [github-tag-action][github-tag-action] is used to automatically\ncreate a new tag when the PR is merged to master.\n\nWhen open a PR meant to generate a new version:\n\n1. Update the `mix.exs` and `README` with the new version.\n\n2. Update [CHANGELOG](CHANGELOG.md) with the new version tight to\n   [semantic versioning][semantic-versioning].\n\n3. Don't forget to include in your commit the tag:\n\n   - `\"#patch\"` for increment `PATCH` version.\n     E.g.: **\"Fix failing tests (#patch)\"**.\n   - `\"#minor\"` for increment `MINOR` version.\n     E.g.: **\"Add Telemetry utility to instrument the projects (#minor)\"**.\n   - `\"#major\"` for increment `MAJOR` version.\n     E.g.: **\"Release x.y.z (#major)\"**.\n\n[github-tag-action]: https://github.com/anothrNick/github-tag-action\n[semantic-versioning]: https://semver.org/spec/v2.0.0.html\n\nIf for some reason GH actions are not working (maybe because we ran out of\nminutes), then push the tag manually, like so:\n\n```\ngit tag -a v0.1.0 -m \"Ratelix version 0.1.0\"\ngit push origin v0.1.0\n```","ref":"readme.html#version-bumps"},{"type":"extras","title":"License - Ratelix","doc":"Apache License 2.0. See the project’s LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThis project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.3.0] - 2025-06-19","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Compliance to hex.pm\n\n## [0.2.0] - 2025-06-19","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Leaky and token bucket implementation\n    - README improvement\n\n## [0.1.0] - 2025-06-17","ref":"changelog.html#added-1"},{"type":"extras","title":"Added - Changelog","doc":"- Initial implementation","ref":"changelog.html#added-2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}